==> open-xchange-subscribe_7.10.4.orig.tar.bz2: open-xchange-subscribe-7.10.4/com.openexchange.subscribe.yahoo/src/com/openexchange/subscribe/yahoo/YahooSubscribeService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.yahoo;

import java.util.Collection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.container.FolderObject;
import com.openexchange.java.Autoboxing;
import com.openexchange.java.Strings;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.yahoo.YahooService;
import com.openexchange.server.ServiceLookup;
import com.openexchange.subscribe.Subscription;
import com.openexchange.subscribe.oauth.AbstractOAuthSubscribeService;

/**
 * {@link YahooSubscribeService}
 *
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class YahooSubscribeService extends AbstractOAuthSubscribeService {

    public static final String SOURCE_ID = "com.openexchange.subscribe.socialplugin.yahoo";
    private final ServiceLookup services;

    /**
     * Initialises a new {@link YahooSubscribeService}.
     * 
     * @param oAuthServiceMetaData The {@link OAuthServiceMetaData}
     * @param services The {@link ServiceLookup}
     */
    public YahooSubscribeService(OAuthServiceMetaData metadata, ServiceLookup services) {
        super(metadata, SOURCE_ID, FolderObject.CONTACT, "Yahoo!", services);
        this.services = services;
    }

    @Override
    public Collection<?> getContent(final Subscription subscription) throws OXException {
        int oauthAccountId = ((Integer) subscription.getConfiguration().get("account")).intValue();
        YahooService yahooService = services.getService(YahooService.class);
        return yahooService.getContacts(subscription.getSession(), subscription.getUserId(), subscription.getContext().getContextId(), oauthAccountId);
    }

    @Override
    public void modifyOutgoing(final Subscription subscription) throws OXException {
        if (Strings.isNotEmpty(subscription.getSecret())) {
            YahooService yahooService = services.getService(YahooService.class);
            // No extra null or empty check, it will be checked on super
            String displayName = yahooService.getAccountDisplayName(subscription.getSession(), subscription.getUserId(), subscription.getContext().getContextId(), Autoboxing.a2i(subscription.getConfiguration().get("account")));
            subscription.setDisplayName(displayName);
        }
        super.modifyOutgoing(subscription);
    }

    @Override
    protected KnownApi getKnownApi() {
        return KnownApi.YAHOO;
    }
}

==> open-xchange-subscribe_7.10.5.orig.tar.bz2: open-xchange-subscribe-7.10.5/com.openexchange.subscribe.yahoo/src/com/openexchange/subscribe/yahoo/YahooSubscribeService.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.subscribe.yahoo;

import java.util.Collection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.container.FolderObject;
import com.openexchange.java.Autoboxing;
import com.openexchange.java.Strings;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.yahoo.YahooService;
import com.openexchange.server.ServiceLookup;
import com.openexchange.subscribe.Subscription;
import com.openexchange.subscribe.oauth.AbstractOAuthSubscribeService;

/**
 * {@link YahooSubscribeService}
 *
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class YahooSubscribeService extends AbstractOAuthSubscribeService {

    public static final String SOURCE_ID = "com.openexchange.subscribe.socialplugin.yahoo";
    private final ServiceLookup services;

    /**
     * Initializes a new {@link YahooSubscribeService}.
     *
     * @param oAuthServiceMetaData The {@link OAuthServiceMetaData}
     * @param services The {@link ServiceLookup}
     * @throws OXException
     */
    public YahooSubscribeService(OAuthServiceMetaData metadata, ServiceLookup services) throws OXException {
        super(metadata, SOURCE_ID, FolderObject.CONTACT, "Yahoo!", services);
        this.services = services;
    }

    @Override
    public Collection<?> getContent(final Subscription subscription) throws OXException {
        int oauthAccountId = ((Integer) subscription.getConfiguration().get("account")).intValue();
        YahooService yahooService = services.getService(YahooService.class);
        return yahooService.getContacts(subscription.getSession(), subscription.getUserId(), subscription.getContext().getContextId(), oauthAccountId);
    }

    @Override
    public void modifyOutgoing(final Subscription subscription) throws OXException {
        if (Strings.isNotEmpty(subscription.getSecret())) {
            YahooService yahooService = services.getService(YahooService.class);
            // No extra null or empty check, it will be checked on super
            String displayName = yahooService.getAccountDisplayName(subscription.getSession(), subscription.getUserId(), subscription.getContext().getContextId(), Autoboxing.a2i(subscription.getConfiguration().get("account")));
            subscription.setDisplayName(displayName);
        }
        super.modifyOutgoing(subscription);
    }

    @Override
    protected KnownApi getKnownApi() {
        return KnownApi.YAHOO;
    }
}
